@@ -86,6 +86,9 @@ __all__ = (
     "DistributionConfigurationTypeDef",
     "DistributionTypeDef",
     "EbsInstanceBlockDeviceSpecificationTypeDef",
+    "FastLaunchConfigurationTypeDef",
+    "FastLaunchLaunchTemplateSpecificationTypeDef",
+    "FastLaunchSnapshotConfigurationTypeDef",
     "FilterTypeDef",
     "GetComponentPolicyRequestRequestTypeDef",
     "GetComponentPolicyResponseTypeDef",
@@ -874,6 +877,7 @@ _OptionalDistributionTypeDef = TypedDict(
         "licenseConfigurationArns": Sequence[str],
         "launchTemplateConfigurations": Sequence["LaunchTemplateConfigurationTypeDef"],
         "s3ExportConfiguration": "S3ExportConfigurationTypeDef",
+        "fastLaunchConfigurations": Sequence["FastLaunchConfigurationTypeDef"],
     },
     total=False,
 )
@@ -898,6 +902,48 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredFastLaunchConfigurationTypeDef = TypedDict(
+    "_RequiredFastLaunchConfigurationTypeDef",
+    {
+        "enabled": bool,
+    },
+)
+_OptionalFastLaunchConfigurationTypeDef = TypedDict(
+    "_OptionalFastLaunchConfigurationTypeDef",
+    {
+        "snapshotConfiguration": "FastLaunchSnapshotConfigurationTypeDef",
+        "maxParallelLaunches": int,
+        "launchTemplate": "FastLaunchLaunchTemplateSpecificationTypeDef",
+        "accountId": str,
+    },
+    total=False,
+)
+
+
+class FastLaunchConfigurationTypeDef(
+    _RequiredFastLaunchConfigurationTypeDef, _OptionalFastLaunchConfigurationTypeDef
+):
+    pass
+
+
+FastLaunchLaunchTemplateSpecificationTypeDef = TypedDict(
+    "FastLaunchLaunchTemplateSpecificationTypeDef",
+    {
+        "launchTemplateId": str,
+        "launchTemplateName": str,
+        "launchTemplateVersion": str,
+    },
+    total=False,
+)
+
+FastLaunchSnapshotConfigurationTypeDef = TypedDict(
+    "FastLaunchSnapshotConfigurationTypeDef",
+    {
+        "targetResourceCount": int,
+    },
+    total=False,
+)
+
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
